<?php
// Include the connection file
require_once 'conn.php';

// Define a variable to hold slide data
$slides = [];

// Attempt to retrieve slides from the database
try {
    // SQL query to select all slides
    $sql = "SELECT * FROM slides";
    $stmt = $conn->query($sql);

    // Check if query execution was successful
    if ($stmt) {
        // Fetch all slides as an associative array
        $slides = $stmt->fetchAll(PDO::FETCH_ASSOC);
    } else {
        // Handle error if query execution fails
        throw new Exception("Error executing query.");
    }
} catch (PDOException $e) {
    // Handle database connection or query execution errors
    echo "Database error: " . $e->getMessage();
    // You might want to log the error or display a user-friendly message
} catch (Exception $e) {
    // Handle other types of exceptions
    echo "Error: " . $e->getMessage();
    // You might want to log the error or display a user-friendly message
}

// Optionally, you can check if slides were retrieved and are not empty
if (empty($slides)) {
    // Display a message if no slides are found
    echo "No slides available.";
}
?>

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Dashboard</title>
    <!-- Bootstrap CSS -->
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <!-- Font Awesome CSS for icons -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.4/css/all.min.css">
    <style>
        /* Additional CSS for styling the logout button */
        .logout-btn {
            position: absolute;
            top: 10px;
            right: 10px;
        }
    </style>
</head>

<body>
    <div class="container mt-5">

        <!-- Logout button -->
        <a href="logout.php" class="btn btn-danger logout-btn"><i class="fas fa-sign-out-alt"></i> Logout</a>
        <div class="container mt-5">
            <div class="row">

                <div class="col-md-6 mb-4">
                    <div class="card">
                        <div class="card-body">
                            <h5 class="card-title">Add New Event</h5>
                            <!-- Replace the existing form with the admin form -->
                            <form action="./add_event.php" method="post" enctype="multipart/form-data">
                                <!-- Form fields for adding a new event -->
                                <div class="form-group">
                                    <label for="event_title">Event Title:</label>
                                    <input type="text" class="form-control" id="event_title" name="event_title" required>
                                </div>
                                <div class="form-group">
                                    <label for="event_theme">Event Theme:</label>
                                    <input type="text" class="form-control" id="event_theme" name="event_theme" required>
                                </div>
                                <div class="form-group">
                                    <label for="event_date">Event Date:</label>
                                    <input type="datetime" class="form-control" id="event_date" name="event_date" required>
                                </div>
                                <div class="form-group">
                                    <label for="event_location">Event Location:</label>
                                    <input type="text" class="form-control" id="event_location" name="event_location" required>
                                </div>
                                <div class="form-group">
                                    <label for="event_image">Event Image:</label>
                                    <input type="file" class="form-control-file" id="event_image" name="event_image" accept="image/*" required>
                                </div>
                                <div class="form-group">
                                    <label for="nigerians_link">Nigerians Link:</label>
                                    <input type="text" class="form-control" id="nigerians_link" name="nigerians_link" required>
                                </div>
                                <div class="form-group">
                                    <label for="foreigners_link">Foreigners Link:</label>
                                    <input type="text" class="form-control" id="foreigners_link" name="foreigners_link" required>
                                </div>
                                <div class="form-group">
                                    <label for="ticket_price">Ticket Price:</label>
                                    <input type="text" class="form-control" id="ticket_price" name="ticket_price" required>
                                </div>
                                <button type="submit" name="addevent" class="btn btn-primary">Add Event</button>
                            </form>

                        </div>
                    </div>
                </div>
                <div class="col-md-6 ">
                    <div class="card">
                        <div class="card-body">
                            <h5 class="card-title">Add MGO Address</h5>
                            <form action="mgo.php" method="post" enctype="multipart/form-data">
                                <div class="form-group">
                                    <label for="event_title">Event Title:</label>
                                    <input type="text" class="form-control" id="event_title" name="event_title" required>
                                </div>
                                <div class="form-group">
                                    <label for="event_theme">Event Theme:</label>
                                    <input type="text" class="form-control" id="event_theme" name="event_theme" required>
                                </div>
                                <div class="form-group">
                                    <label for="event_speaker">MGO's Name:</label>
                                    <input type="text" class="form-control" id="event_speaker" name="event_speaker" required>
                                </div>
                                <div class="form-group">
                                    <label for="event_date">Event Date:</label>
                                    <input type="date" class="form-control" id="event_date" name="event_date" required>
                                </div>
                                <div class="form-group">
                                    <label for="event_location">Event Location:</label>
                                    <input type="text" class="form-control" id="event_location" name="event_location" required>
                                </div>
                                <div class="form-group">
                                    <label for="event_description">MGO's Address:</label>
                                    <textarea class="form-control" id="event_description" name="event_description" rows="3" required></textarea>
                                </div>
                                <div class="form-group">
                                    <label for="event_image">Event Image:</label>
                                    <input type="file" class="form-control-file" id="event_image" name="event_image" accept="image/*" required>
                                </div>
                                <button type="submit" name="add_event" class="btn btn-primary">Add Address</button>
                            </form>
                        </div>
                    </div>
                </div>
 <div class="col-md-6 mb-4">
                    <div class="card">
                        <div class="card-body">
                            <h5 class="card-title">Add New Slide</h5>
                            <form action="add_slide.php" method="post" enctype="multipart/form-data">
                                <!-- Form fields for adding a new slide -->
                                <div class="form-group">
                                    <label for="image">Image:</label>
                                    <input type="file" class="form-control-file" id="image" name="image" accept="image/*" required>
                                </div>
                                <div class="form-group">
                                    <label for="title">Title:</label>
                                    <input type="text" class="form-control" id="title" name="title">
                                </div>
                                <div class="form-group">
                                    <label for="subtitle">Subtitle:</label>
                                    <input type="text" class="form-control" id="subtitle" name="subtitle">
                                </div>
                                <div class="form-group">
                                    <label for="link">Link:</label>
                                    <input type="text" class="form-control" id="link" name="link" >
                                </div>
                                <button type="submit" class="btn btn-primary">Add Slide</button>
                            </form>
                        </div>
                    </div>
                </div>


                <div class="col-md-6 mb-4">
                    <div class="card">
                        <div class="card-body">
                            <h5 class="card-title">Add New Speaker</h5>
                            <form method="post" enctype="multipart/form-data" action="add_speakers.php">
                                <div class="form-group">
                                    <label for="name">Name:</label>
                                    <input type="text" class="form-control" id="name" name="name" required>
                                </div>
                                <div class="form-group">
                                    <label for="position">Position:</label>
                                    <input type="text" class="form-control" id="position" name="position" required>
                                </div>
                                <div class="form-group">
                                    <label for="image">Image:</label>
                                    <input type="file" class="form-control-file" id="image" name="image" accept="image/*" required>
                                </div>
                                <button type="submit" class="btn btn-primary">Add Speaker</button>
                            </form>
                        </div>
                    </div>

                   


                    <!-- Add more columns with forms as needed -->

                   <!-- Display slides and delete buttons -->
<div class="col-md-12">
    <h5>Slides</h5>
    <div class="row">
        <?php
        // Check if slides are available
        if ($slides) {
            // Loop through slides and display them with delete buttons
            foreach ($slides as $slide) {
                echo '<div class="col-md-4 mb-3">';
                echo '<div class="card">';

                // Check if it's an image or video and display accordingly
                if (!empty($slide['image_url'])) {
                    // Display image slide
                    echo '<img src="' . $slide['image_url'] . '" class="card-img-top img-fluid" alt="' . $slide['title'] . '">'; // Image
                } elseif (!empty($slide['video_url'])) {
                    // Display video slide
                    echo '<div class="video-container">';
                    echo '<video controls class="card-img-top img-fluid">';
                    echo '<source src="' . $slide['video_url'] . '" type="video/mp4">';
                    echo 'Your browser does not support the video tag.';
                    echo '</video>';
                    echo '</div>';
                }

                echo '<div class="card-body">';
                echo '<h6 class="card-title">' . $slide['title'] . '</h6>';
                echo '<p class="card-text">' . $slide['subtitle'] . '</p>';
                echo '<a href="' . $slide['link'] . '" class="btn btn-sm btn-primary mr-2">Link</a>'; // Link button

                // Delete button with form for each slide
                echo '<form action="manage_slide.php" method="post" class="d-inline">';
                echo '<input type="hidden" name="action" value="delete">';
                echo '<input type="hidden" name="slide_id" value="' . $slide['id'] . '">';
                echo '<button type="submit" class="btn btn-sm btn-danger">Delete</button>'; // Delete button
                echo '</form>';
                
                echo '</div>'; // Close card-body
                echo '</div>'; // Close card
                echo '</div>'; // Close col-md-4
            }
        } else {
            // Display message if no slides are available
            echo '<p>No slides available.</p>';
        }
        ?>
    </div>
</div>

                    <div class="col-md-12 mb-6">
                        <div class="card">
                            <h5 class="card-title">Add Upcoming Events</h5>
                            <div class="card-body">
                                <form action="add_upcomingevents.php" method="POST" enctype="multipart/form-data">
                                    <div class="form-group">
                                        <label for="title">Title:</label>
                                        <input type="text" class="form-control" id="title" name="title">
                                    </div>

                                    <div class="form-group">
                                        <label for="date">Date:</label>
                                        <input type="datetime" class="form-control" id="date" name="date">
                                    </div>

                                    <div class="form-group">
                                        <label for="ticket_price">Ticket Price:</label>
                                        <input type="text" class="form-control" id="ticket_price" name="ticket_price">
                                    </div>

                                    <div class="form-group">
                                        <label for="start_time">Start Time:</label>
                                        <input type="text" class="form-control" id="start_time" name="start_time">
                                    </div>

                                    <div class="form-group">
                                        <label for="location">Location:</label>
                                        <input type="text" class="form-control" id="location" name="location">
                                    </div>

                                    <div class="form-group">
                                        <label for="image">Image:</label>
                                        <input type="file" class="form-control-file" id="image" name="image">
                                    </div>

                                    <div class="form-group">
                                        <label for="registration_link">Registration Link:</label>
                                        <input type="text" class="form-control" id="registration_link" name="registration_link">
                                    </div>

                                    <button type="submit" class="btn btn-primary">Submit</button>
                                </form>
                            </div>
                        </div>
                    </div>


                    <!-- Bootstrap JS (optional, only needed if you're using Bootstrap JavaScript features) -->
                    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
</body>

</html>