<?php
// Include database connection
include 'conn.php';

// Handle record insertion
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action']) && $_POST['action'] === 'insert') {
    $title = $_POST['title'];
    $video_url = $_POST['video_url'];
    $date = $_POST['date'];
    $time_details = $_POST['time_details'];
    $footer_text = $_POST['footer_text'];

    // Handle the file upload
    $image_url = '';
    if (isset($_FILES['image_url']) && $_FILES['image_url']['error'] === UPLOAD_ERR_OK) {
        $fileTmpPath = $_FILES['image_url']['tmp_name'];
        $fileName = $_FILES['image_url']['name'];
        $fileSize = $_FILES['image_url']['size'];
        $fileType = $_FILES['image_url']['type'];
        $fileNameCmps = explode('.', $fileName);
        $fileExtension = strtolower(end($fileNameCmps));

        // Check if file extension is allowed
        $allowedExtensions = ['jpg', 'jpeg', 'png', 'gif'];
        if (in_array($fileExtension, $allowedExtensions)) {
            // Directory where the file will be stored
            $uploadDir = 'uploads/';
            $newFileName = md5(time() . $fileName) . '.' . $fileExtension;
            $dest_path = $uploadDir . $newFileName;

            if (move_uploaded_file($fileTmpPath, $dest_path)) {
                $image_url = $dest_path;
            } else {
                echo "<div class='alert alert-danger'>Error moving the uploaded file.</div>";
            }
        } else {
            echo "<div class='alert alert-danger'>Invalid file extension.</div>";
        }
    }

    // Prepare and execute the SQL query
    $stmt = $conn->prepare("INSERT INTO modal_info (title, image_url, video_url, date, time_details, footer_text) VALUES (?, ?, ?, ?, ?, ?)");
    $stmt->execute([$title, $image_url, $video_url, $date, $time_details, $footer_text]);

    echo "<div class='alert alert-success'>Data inserted successfully!</div>";
}

// Handle record deletion
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action']) && $_POST['action'] === 'delete') {
    $id = $_POST['id'];

    // Prepare and execute the SQL query
    $stmt = $conn->prepare("DELETE FROM modal_info WHERE id = ?");
    $stmt->execute([$id]);

    echo "<div class='alert alert-success'>Record deleted successfully!</div>";
}

// Fetch all records for display
$stmt = $conn->query("SELECT * FROM modal_info ORDER BY date DESC");
$records = $stmt->fetchAll();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Admin - Modal Data</title>
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
</head>
<body>
    <div class="container mt-5">
        <h2>Admin - Add/Edit Modal Data</h2>
        <form action="adminmodal.php" method="POST" enctype="multipart/form-data">
            <input type="hidden" name="action" value="insert">
            <div class="form-group">
                <label for="title">Title</label>
                <input type="text" class="form-control" id="title" name="title" required>
            </div>
            <div class="form-group">
                <label for="image_url">Image</label>
                <input type="file" class="form-control-file" id="image_url" name="image_url" required>
            </div>
            <div class="form-group">
                <label for="video_url">Video URL</label>
                <input type="text" class="form-control" id="video_url" name="video_url" required>
            </div>
            <div class="form-group">
                <label for="date">Date</label>
                <input type="datetime-local" class="form-control" id="date" name="date" required>
            </div>
            <div class="form-group">
                <label for="time_details">Time Details</label>
                <textarea class="form-control" id="time_details" name="time_details" required></textarea>
            </div>
            <div class="form-group">
                <label for="footer_text">Footer Text</label>
                <input type="text" class="form-control" id="footer_text" name="footer_text" required>
            </div>
            <button type="submit" class="btn btn-primary">Submit</button>
        </form>

        <h2 class="mt-5">Manage Records</h2>
        <table class="table table-striped">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Title</th>
                    <th>Image</th>
                    <th>Video URL</th>
                    <th>Date</th>
                    <th>Time Details</th>
                    <th>Footer Text</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($records as $record): ?>
                    <tr>
                        <td><?php echo htmlspecialchars($record['id']); ?></td>
                        <td><?php echo htmlspecialchars($record['title']); ?></td>
                        <td><img src="<?php echo htmlspecialchars($record['image_url']); ?>" alt="Image" width="100"></td>
                        <td><?php echo htmlspecialchars($record['video_url']); ?></td>
                        <td><?php echo htmlspecialchars($record['date']); ?></td>
                        <td><?php echo htmlspecialchars($record['time_details']); ?></td>
                        <td><?php echo htmlspecialchars($record['footer_text']); ?></td>
                        <td>
                            <form action="adminmodal.php" method="POST" style="display:inline;">
                                <input type="hidden" name="action" value="delete">
                                <input type="hidden" name="id" value="<?php echo htmlspecialchars($record['id']); ?>">
                                <button type="submit" class="btn btn-danger">Delete</button>
                            </form>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>
    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.5.2/dist/umd/popper.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
</body>
</html>
