<?php
// Include the connection file
require_once 'conn.php';

// Retrieve slides from the database
$sql = "SELECT * FROM slides";
$stmt = $conn->query($sql);

// Check if slides are retrieved successfully
if ($stmt) {
    // Assign the retrieved slides to the $slides variable
    $slides = $stmt->fetchAll(PDO::FETCH_ASSOC);
} else {
    // Handle error if slides cannot be retrieved
    echo "Error retrieving slides from the database.";
    // You might want to log the error or display a user-friendly message
}

// Retrieve gallery items from the database
$sql_gallery = "SELECT * FROM gallery";
$stmt_gallery = $conn->query($sql_gallery);

// Check if gallery items are retrieved successfully
if ($stmt_gallery) {
    // Assign the retrieved gallery items to the $gallery variable
    $gallery = $stmt_gallery->fetchAll(PDO::FETCH_ASSOC);
} else {
    // Handle error if gallery items cannot be retrieved
    echo "Error retrieving gallery items from the database.";
    // You might want to log the error or display a user-friendly message
}
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $title = $_POST['title'];
    $date = $_POST['date'];
    $ticket_price = $_POST['ticket_price'];
    $start_time = $_POST['start_time'];
    $location = $_POST['location'];
    $registration_link = $_POST['registration_link'];

    // Image upload
    if (isset($_FILES['image']) && $_FILES['image']['error'] == 0) {
        $image = $_FILES['image']['name'];
        $target_dir = "uploads/";
        $target_file = $target_dir . basename($image);

        // Move the uploaded file to the target directory
        if (move_uploaded_file($_FILES['image']['tmp_name'], $target_file)) {
            try {
                // Prepare an SQL statement
                $stmt = $conn->prepare("INSERT INTO dtceupcoming (title, date, ticket_price, start_time, location, image, registration_link) VALUES (:title, :date, :ticket_price, :start_time, :location, :image, :registration_link)");

                // Bind parameters
                $stmt->bindValue(':title', $title);
                $stmt->bindValue(':date', $date);
                $stmt->bindValue(':ticket_price', $ticket_price);
                $stmt->bindValue(':start_time', $start_time);
                $stmt->bindValue(':location', $location);
                $stmt->bindValue(':image', $image);
                $stmt->bindValue(':registration_link', $registration_link);

                // Execute the statement
                if ($stmt->execute()) {
                    echo "<p>Event added successfully.</p>";
                } else {
                    echo "<p>Error adding event: " . $stmt->errorInfo()[2] . "</p>";
                }
            } catch (PDOException $e) {
                echo "<p>Error: " . $e->getMessage() . "</p>";
            }
        } else {
            echo "<p>Error uploading image.</p>";
        }
    } else {
        echo "<p>No image uploaded or upload error.</p>";
    }
}
?>

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Dashboard</title>
    <!-- Bootstrap CSS -->
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <!-- Font Awesome CSS for icons -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.4/css/all.min.css">
    <style>
        /* Additional CSS for styling the logout button */
        .logout-btn {
            position: absolute;
            top: 10px;
            right: 10px;
        }
    </style>
</head>

<body>
    <div class="container mt-5">

        <!-- Logout button -->
        <a href="logout.php" class="btn btn-danger logout-btn"><i class="fas fa-sign-out-alt"></i> Logout</a>
        <div class="container mt-5">
            <div class="row">

                <!-- Existing Event and MGO Address Forms -->
                <!-- Your existing forms here... -->

                <!-- New Gallery Section -->
                <div class="col-md-12 mb-4">
                    <div class="card">
                        <div class="card-body">
                            <h5 class="card-title">Add New Gallery Item</h5>
                            <form action="add_gallery.php" method="post" enctype="multipart/form-data">
                                <div class="form-group">
                                    <label for="type">Type:</label>
                                    <select class="form-control" id="type" name="type" required>
                                        <option value="photo">Photo</option>
                                        <option value="video">Video</option>
                                    </select>
                                </div>
                                <div class="form-group">
                                    <label for="title">Title:</label>
                                    <input type="text" class="form-control" id="title" name="title" required>
                                </div>
                                <div class="form-group">
                                    <label for="description">Description:</label>
                                    <textarea class="form-control" id="description" name="description" rows="3" required></textarea>
                                </div>
                                <div class="form-group">
                                    <label for="image_path">Image Path:</label>
                                    <input type="file" class="form-control-file" id="image_path" name="image_path" accept="image/*" required>
                                </div>
                                <div class="form-group">
                                    <label for="url">Video URL (for videos only):</label>
                                    <input type="text" class="form-control" id="url" name="url">
                                </div>
                                <button type="submit" class="btn btn-primary">Add Gallery Item</button>
                            </form>
                        </div>
                    </div>
                </div>

                <!-- Display Existing Gallery Items -->
                <div class="col-md-12 mb-4">
                    <div class="card">
                        <div class="card-body">
                            <h5 class="card-title">Manage Gallery Items</h5>
                            <div class="row">
                                <?php if ($gallery): ?>
                                    <?php foreach ($gallery as $item): ?>
                                        <div class="col-md-4 mb-3">
                                            <div class="card">
                                                <img src="<?php echo htmlspecialchars($item['image_path']); ?>" class="card-img-top img-fluid" alt="<?php echo htmlspecialchars($item['title']); ?>">
                                                <div class="card-body">
                                                    <h6 class="card-title"><?php echo htmlspecialchars($item['title']); ?></h6>
                                                    <p class="card-text"><?php echo htmlspecialchars($item['description']); ?></p>
                                                    <?php if ($item['type'] == 'video'): ?>
                                                        <a href="<?php echo htmlspecialchars($item['url']); ?>" class="btn btn-sm btn-primary">Watch Video</a>
                                                    <?php endif; ?>
                                                    <form action="manage_gallery.php" method="post" class="d-inline">
                                                        <input type="hidden" name="action" value="delete">
                                                        <input type="hidden" name="gallery_id" value="<?php echo htmlspecialchars($item['id']); ?>">
                                                        <button type="submit" class="btn btn-sm btn-danger">Delete</button>
                                                    </form>
                                                </div>
                                            </div>
                                        </div>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <p>No gallery items available.</p>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Existing Slide and Speaker Forms -->
                <!-- Your existing forms here... -->
<div class="container mt-5">
    <h2>Upload New Event</h2>
    <form action="galleryadmin.php" method="post" enctype="multipart/form-data">
        <div class="form-group">
            <label for="title">Event Title:</label>
            <input type="text" class="form-control" id="title" name="title" required>
        </div>
        <div class="form-group">
            <label for="date">Event Date:</label>
            <input type="date" class="form-control" id="date" name="date" required>
        </div>
        <div class="form-group">
            <label for="ticket_price">Ticket Price:</label>
            <input type="text" class="form-control" id="ticket_price" name="ticket_price" required>
        </div>
        <div class="form-group">
            <label for="start_time">Start Time:</label>
            <input type="time" class="form-control" id="start_time" name="start_time" required>
        </div>
        <div class="form-group">
            <label for="location">Location:</label>
            <input type="text" class="form-control" id="location" name="location" required>
        </div>
        <div class="form-group">
            <label for="image">Event Image:</label>
            <input type="file" class="form-control-file" id="image" name="image" accept="image/*" required>
        </div>
        <div class="form-group">
            <label for="registration_link">Registration Link:</label>
            <input type="url" class="form-control" id="registration_link" name="registration_link" required>
        </div>
        <button type="submit" class="btn btn-primary">Upload Event</button>
    </form>
</div>

            </div>
        </div>
    </div>

    <!-- Bootstrap JS (optional, only needed if you're using Bootstrap JavaScript features) -->
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
</body>

</html>
