<?php
// Include the connection file
require_once 'conn.php';

// Check if the form is submitted
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Check which action is selected
    $action = $_POST['action'];

    // Handle the selected action
    switch ($action) {
        case 'add':
            // Handle adding a new slide
            $title = $_POST['title'];
            $subtitle = $_POST['subtitle'];
            $link = $_POST['link'];

            // File upload handling
            $file = $_FILES['file']['name'];
            $target_dir = "uploads/"; // Directory where files will be uploaded
            $target_file = $target_dir . basename($file);
            $uploadOk = 1;
            $fileType = strtolower(pathinfo($target_file, PATHINFO_EXTENSION));

            // Check if the file is an image or video
            $isImage = isset($_FILES['file']) && !empty(getimagesize($_FILES['file']['tmp_name']));
            $isVideo = isset($_FILES['file']) && in_array($fileType, ['mp4', 'avi', 'mov', 'wmv']);

            if ($isImage) {
                // Validate image file
                $check = getimagesize($_FILES['file']['tmp_name']);
                if ($check === false) {
                    $uploadOk = 0;
                    echo "File is not an image.";
                }
            } elseif ($isVideo) {
                // Validate video file
                if (!in_array($fileType, ['mp4', 'avi', 'mov', 'wmv'])) {
                    $uploadOk = 0;
                    echo "Sorry, only MP4, AVI, MOV, and WMV files are allowed.";
                }
            } else {
                $uploadOk = 0;
                echo "File is not a valid image or video.";
            }

            // Check if file already exists
            if (file_exists($target_file)) {
                $uploadOk = 0;
                echo "Sorry, file already exists.";
            }

            // Check file size
            if ($_FILES["file"]["size"] > 10000000) { // Increase size limit for videos
                $uploadOk = 0;
                echo "Sorry, your file is too large.";
            }

            // Check if $uploadOk is set to 0 by an error
            if ($uploadOk == 0) {
                echo "Sorry, your file was not uploaded.";
            } else {
                if (move_uploaded_file($_FILES['file']['tmp_name'], $target_file)) {
                    // Prepare and execute SQL statement to insert data into the database
                    $sql = "INSERT INTO slides (image_url, video_url, title, subtitle, link) VALUES (:image_url, :video_url, :title, :subtitle, :link)";
                    $stmt = $conn->prepare($sql);
                    
                    if ($isImage) {
                        $stmt->bindParam(':image_url', $target_file);
                        $stmt->bindValue(':video_url', null, PDO::PARAM_NULL);
                    } elseif ($isVideo) {
                        $stmt->bindValue(':image_url', null, PDO::PARAM_NULL);
                        $stmt->bindParam(':video_url', $target_file);
                    }

                    $stmt->bindParam(':title', $title);
                    $stmt->bindParam(':subtitle', $subtitle);
                    $stmt->bindParam(':link', $link);

                    try {
                        if ($stmt->execute()) {
                            echo "Slide added successfully.";
                        } else {
                            echo "Error adding slide.";
                        }
                    } catch (PDOException $e) {
                        echo "Error: " . $e->getMessage();
                    }
                } else {
                    echo "Sorry, there was an error uploading your file.";
                }
            }
            break;

        case 'delete':
            // Handle deleting a slide
            $slide_id = $_POST['slide_id'];
        
            // Fetch slide details to get the file URL
            $stmt = $conn->prepare("SELECT * FROM slides WHERE id = ?");
            $stmt->execute([$slide_id]);
            $slide = $stmt->fetch();
        
            if ($slide) {
                // Delete slide from the database
                $sql = "DELETE FROM slides WHERE id = ?";
                $stmt = $conn->prepare($sql);
                $stmt->execute([$slide_id]);
        
                // Delete file from the folder
                $file_path = $slide['image_url'] ? $slide['image_url'] : $slide['video_url'];
                if (file_exists($file_path)) {
                    unlink($file_path);
                }
                
                // Redirect back to admin panel or display success message
                header('Location: admin.php');
                exit();
            } else {
                echo "Slide not found.";
            }
            break;

        case 'replace':
            // Handle replacing a slide
            $slide_id = $_POST['slide_id'];
            $title = $_POST['title'];
            $subtitle = $_POST['subtitle'];
            $link = $_POST['link'];

            // File upload handling
            $file = $_FILES['file']['name'];
            $target_dir = "uploads/"; // Directory where files will be uploaded
            $target_file = $target_dir . basename($file);
            $uploadOk = 1;
            $fileType = strtolower(pathinfo($target_file, PATHINFO_EXTENSION));

            // Check if the file is an image or video
            $isImage = isset($_FILES['file']) && !empty(getimagesize($_FILES['file']['tmp_name']));
            $isVideo = isset($_FILES['file']) && in_array($fileType, ['mp4', 'avi', 'mov', 'wmv']);

            if ($isImage) {
                // Validate image file
                $check = getimagesize($_FILES['file']['tmp_name']);
                if ($check === false) {
                    $uploadOk = 0;
                    echo "File is not an image.";
                }
            } elseif ($isVideo) {
                // Validate video file
                if (!in_array($fileType, ['mp4', 'avi', 'mov', 'wmv'])) {
                    $uploadOk = 0;
                    echo "Sorry, only MP4, AVI, MOV, and WMV files are allowed.";
                }
            } else {
                $uploadOk = 0;
                echo "File is not a valid image or video.";
            }

            // Check if file size
            if ($_FILES["file"]["size"] > 10000000) { // Increase size limit for videos
                $uploadOk = 0;
                echo "Sorry, your file is too large.";
            }

            // Check if $uploadOk is set to 0 by an error
            if ($uploadOk == 0) {
                echo "Sorry, your file was not uploaded.";
            } else {
                // Fetch existing slide details to get the old file URL
                $stmt = $conn->prepare("SELECT * FROM slides WHERE id = ?");
                $stmt->execute([$slide_id]);
                $slide = $stmt->fetch();

                if ($slide) {
                    // Delete old file from the folder
                    $old_file_path = $slide['image_url'] ? $slide['image_url'] : $slide['video_url'];
                    if (file_exists($old_file_path)) {
                        unlink($old_file_path);
                    }

                    // Upload new file to server
                    if (move_uploaded_file($_FILES['file']['tmp_name'], $target_file)) {
                        // Update slide details in the database
                        $sql = "UPDATE slides SET image_url = :image_url, video_url = :video_url, title = :title, subtitle = :subtitle, link = :link WHERE id = :slide_id";
                        $stmt = $conn->prepare($sql);

                        if ($isImage) {
                            $stmt->bindParam(':image_url', $target_file);
                            $stmt->bindValue(':video_url', null, PDO::PARAM_NULL);
                        } elseif ($isVideo) {
                            $stmt->bindValue(':image_url', null, PDO::PARAM_NULL);
                            $stmt->bindParam(':video_url', $target_file);
                        }

                        $stmt->bindParam(':title', $title);
                        $stmt->bindParam(':subtitle', $subtitle);
                        $stmt->bindParam(':link', $link);
                        $stmt->bindParam(':slide_id', $slide_id, PDO::PARAM_INT);

                        try {
                            if ($stmt->execute()) {
                                echo "Slide replaced successfully.";
                            } else {
                                echo "Error replacing slide.";
                            }
                        } catch (PDOException $e) {
                            echo "Error: " . $e->getMessage();
                        }
                    } else {
                        echo "Sorry, there was an error uploading your file.";
                    }
                } else {
                    echo "Slide not found.";
                }
            }
            break;

        default:
            // Invalid action
            echo "Invalid action!";
            break;
    }

    // Redirect back to the admin panel after processing the action
    header("Location: admin.php");
    exit();
} else {
    // If the form is not submitted, redirect back to the admin panel
    header("Location: admin.php");
    exit();
}
?>
